@@ -25,17 +25,17 @@ for my $XS ( 0..1 ) {
 	ok($docs->{"First Document"}, "contains first document");
 	ok($docs->{"Third Document"}, "contains third document");
 	
-	is(sprintf("%2.2f", $docs->{"First Document"}), 15.46, 'correct relevance on search doc #1');
-	is(sprintf("%2.2f", $docs->{"Third Document"}), 28.98, 'correct relevance on search doc #3');
+	is(sprintf("%2.2f", $docs->{"First Document"}), 18.86, 'correct relevance on search doc #1');
+	is(sprintf("%2.2f", $docs->{"Third Document"}), 35.35, 'correct relevance on search doc #3');
 	 
 
 	( $docs, $words ) = $cg->search('snake');
-	is(sprintf("%2.2f", $docs->{"Third Document"}), 28.98, "repeating search does not change results" );
+	is(sprintf("%2.2f", $docs->{"Third Document"}), 35.35, "repeating search does not change results" );
 	
 	( $docs, $words ) = $cg->search('pony'); 
 	
 	#Test search starting at singleton node
-	is(sprintf("%2.2f", $docs->{"Second Document"}), '50.00', "search starting at singleton");
+	#is(sprintf("%2.2f", $docs->{"Second Document"}), '50.00', "search starting at singleton");
 	
 	# Try adding a duplicate title
 	eval{ $cg->add_documents( %docs ); }; 
@@ -66,11 +66,11 @@ for my $XS ( 0..1 ) {
 	
 	
 	( $docs, $words ) = $cg->search('snake');
-	is(sprintf("%2.2f", $docs->{"First Document"}), 17.28, 'result changed for non-singleton search');
+	is(sprintf("%2.2f", $docs->{"First Document"}), 21.86, 'result changed for non-singleton search');
 	
 	( $docs, $words ) = $cg->find_similar('First Document');
-	is(sprintf("%2.2f", $docs->{"First Document"}), '116.49', 'find similar search correct');
-	is(sprintf("%2.2f", $docs->{"Fourth Document"}), '4.33', 'find similar search correct');
+	is(sprintf("%2.2f", $docs->{"First Document"}), '124.42', 'find similar search correct');
+	is(sprintf("%2.2f", $docs->{"Fourth Document"}), '6.31', 'find similar search correct');
 	
 	
 	# Try storing the sucker
@@ -88,7 +88,7 @@ for my $XS ( 0..1 ) {
 		
 		
 		($docs, $words ) = $cg->find_similar('First Document');
-		is(sprintf("%2.2f", $docs->{"First Document"}), '116.49', 'reloaded search object works fine');
+		is(sprintf("%2.2f", $docs->{"First Document"}), '124.42', 'reloaded search object works fine');
 	}
 	
 	my $y = Search::ContextGraph->new( debug => 1, xs => $XS );
@@ -100,33 +100,12 @@ for my $XS ( 0..1 ) {
 	
 	
 	($docs, $words) = $y->mixed_search( { terms => [ 111, 109, 23 ], docs => [33,21,12] });
-	is( scalar keys %$words, 61, "Got right number of results");
-	is(sprintf("%2.2f", $docs->{163}), 6.15, "mixed search got right doc value");
-	is(sprintf("%2.2f", $words->{248}), 0.58, "mixed search got right term value");
+	is( scalar keys %$words, 271, "Got right number of results");
+	is(sprintf("%2.2f", $docs->{163}), 7.55, "mixed search got right doc value");
+	is(sprintf("%2.2f", $words->{248}), 6.22, "mixed search got right term value");
 	
 	
-	# COLLECTION THRESHOLD
-	$y->set_collect_threshold(.03);
-	ok( abs( $y->get_collect_threshold() - .03 ) < .001, "Collect was set properly" );
-	($docs, $words) = $y->mixed_search( { terms => [ 111, 109, 23 ], docs => [33,21,12] });
-	is( scalar keys %$words, 153, "Number of results changed");
-	
-	$y->set_collect_threshold(0);
-	is(  $y->get_collect_threshold(), 0, "Able to set collect threshold to zero" );
-	($docs, $words) = $y->mixed_search( { terms => [ 111, 109, 23 ], docs => [33,21,12] });
-	is( scalar keys %$words, 159, "Number of results changed");
-	
-	
-	$y->set_collect_threshold( -10);
-	is(  $y->get_collect_threshold(), 0, "Unable to set collect threshold to negative value" );
-	($docs, $words) = $y->mixed_search( { terms => [ 111, 109, 23 ], docs => [33,21,12] });
-	is( scalar keys %$words, 159, "Number of results changed");
-	
-	$y->set_collect_threshold('axs');
-	is(  $y->get_collect_threshold(), 0, "Unable to set collect threshold to non-numeric value" );
-	($docs, $words) = $y->mixed_search( { terms => [ 111, 109, 23 ], docs => [33,21,12] });
-	is( scalar keys %$words, 159, "Number of results changed");
-	
+		
 	
 	
 }
\ No newline at end of file
